library(testthat)
library(coreSim)
library(car)
library(survival)

test_check("coreSim", report = 'summary')
